@@ -12,7 +12,7 @@ Numeric = Union[Number, NPNumeric, TFNumeric]
 
 from plum import clear_all_cache as _clear_all_cache
 
-import tensorflow as tf
+import tensorflow as tf  # Load `tensorflow` to load all new types.
 
 # noinspection PyUnresolvedReferences
 from .generic import *
